@@ -26,6 +26,7 @@
 #include "LayoutManager.h"
 #include "LegendVisitor.h"
 #include "TextVisitor.h"
+#include "Polyline.h"
 
 using namespace magics;
 
@@ -152,6 +153,7 @@ void FortranSceneNode::getReady() {
                    Colour("white"));
 
     BasicSceneObject::getReady();
+    if ( skinny_ ) Polyline::skinnyMode();
 }
 
 FortranSceneNode::~FortranSceneNode() {}
