@@ -215,6 +215,13 @@ public:
     Polyline();
     ~Polyline();
 
+    static bool skinny_;
+
+    static void skinnyMode() {
+        skinny_ = true;
+        
+    }
+
     void reproject(const Transformation&);
     bool reproject(BasicGraphicsObjectContainer& out) const;
     void redisplay(const BaseDriver& driver) const;
